"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.afterEach = exports.beforeEach = void 0;
const assert_js_1 = require("../modules/assert.js");
const status = {
    before: true,
    after: true,
};
/**
 * - ✅ Handling **global** and **external** services (_preparing a database, for example_)
 * - ✅ It's made for **exclusive use** in combination with **Poku**'s **`assert`** methods
 * - ❌ Changing local variables values and states ([_use a mock instead_](https://poku.dev/docs/category/mock))
 *
 * ---
 *
 * ### Available methos:
 *
 * ```ts
 * import { assert, beforeEach } from 'poku';
 *
 * const before = beforeEach(() => {
 *   // preparing an external or global state
 * };
 *
 * before.pause();
 * before.continue();
 * before.reset();
 * ```
 */
const beforeEach = (callback) => {
    assert_js_1.each.before = () => {
        if (status.before)
            callback();
    };
    const pause = () => {
        status.before = false;
    };
    const continueFunc = () => {
        status.before = true;
    };
    const reset = () => {
        assert_js_1.each.before = undefined;
    };
    return { pause, continue: continueFunc, reset };
};
exports.beforeEach = beforeEach;
/**
 * - ✅ Handling **global** and **external** services (_preparing a database, for example_)
 * - ✅ It's made for **exclusive use** in combination with **Poku**'s **`assert`** methods
 * - ❌ Changing local variables values and states ([_use a mock instead_](https://poku.dev/docs/category/mock))
 *
 * ---
 *
 * ### Available methos:
 *
 * ```ts
 * import { assert, afterEach } from 'poku';
 *
 * const after = afterEach(() => {
 *   // cleanup an external or global state
 * };
 *
 * after.pause();
 * after.continue();
 * after.reset();
 * ```
 */
const afterEach = (callback) => {
    assert_js_1.each.after = () => {
        if (status.after)
            callback();
    };
    const pause = () => {
        status.after = false;
    };
    const continueFunc = () => {
        status.after = true;
    };
    const reset = () => {
        assert_js_1.each.after = undefined;
    };
    return { pause, continue: continueFunc, reset };
};
exports.afterEach = afterEach;
